pub struct BlockSignature {
pub node_id: NodeId,
pub signature: Signature,
}Expand description
Represents a signature of the block by one node, using its own key to sign the block’s hash.
Fields
node_id: NodeIdsignature: SignatureImplementations
Sourceimpl BlockSignature
impl BlockSignature
pub fn new(node_id: NodeId, signature: Signature) -> BlockSignature
pub fn copy_into_builder(&self, builder: &mut Builder<'_>)