BlockSignatures

Struct BlockSignatures 

pub struct BlockSignatures { /* private fields */ }
Represents signatures stored in a block. Since a node writes a block as soon as it has enough signatures, signatures can differ from one node to the other. Signatures frame is pre-allocated, which means that not all signatures may fit. But in theory, it should always contain enough space for all nodes to add their own signature.

Implementations

Source

impl BlockSignatures

pub fn new_from_signatures(signatures: Vec<BlockSignature>) -> BlockSignatures

pub fn empty_signatures_for_nodes(cell: &Cell) -> BlockSignatures

Create signatures with pre-allocated space for the number of nodes we have in the cell

pub fn to_frame_for_new_block( &self, operations_size: BlockOperationsSize, ) -> Result<SignaturesFrame<Bytes>, Error>

pub fn to_frame_for_existing_block( &self, header_reader: &Reader<'_>, ) -> Result<SignaturesFrame<Bytes>, Error>

pub fn read_frame<I: FrameReader>(inner: I) -> Result<SignaturesFrame<I>, Error>

pub fn read_frame_from_next_offset<I: FrameReader>( inner: I, next_offset: usize, ) -> Result<SignaturesFrame<I>, Error>