pub struct SyncState {
pub pending_last_cleanup_block: Option<(BlockOffset, BlockHeight)>,
}Expand description
State of the synchronization, used to communicate information between the
ChainSynchronizer, CommitManager and PendingSynchronizer.
Fields
pending_last_cleanup_block: Option<(BlockOffset, BlockHeight)>Indicates what is the last block that got cleaned up from pending store,
and that is now only available from the chain. This is used by the
PendingSynchronizer to know which operations it should not include
anymore in its requests.